/*
 * Klogwatch, Netfilter log monitor
 *
 * Copyright (C) 2004 Nick Battle <nick.battle@freeuk.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2, or (at your option) any
 * later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 */

#include <qdir.h>
#include "klogconfig.h"
#include "debug.h"

KLogConfig::KLogConfig()
{
    load();
}

KLogConfig::~KLogConfig()
{
    save();
    me = NULL;
}

KLogConfig *KLogConfig::me;

KLogConfig *KLogConfig::getConfig()
{
    if (me == NULL)
    {
	debug("Creating config\n");
	me = new KLogConfig();
    }
    else
    {
	debug("Returning config\n");
    }

    return me;
}

void KLogConfig::load()
{
    QSettings file;
    debug("Loading config\n");

    file.beginGroup("qlogwatch");
    file.beginGroup("Timings");
    POLLTIME = file.readNumEntry("/POLLTIME", _POLLTIME);
    PAUSETIME = file.readNumEntry("/PAUSETIME", _PAUSETIME);
    SHOWTIME = file.readNumEntry("/SHOWTIME", _SHOWTIME);
    file.endGroup();

    file.beginGroup("General");
    MINLINES = file.readNumEntry("/MINLINES", _MINLINES);
    BUFFSIZE = file.readNumEntry("/BUFFSIZE", _BUFFSIZE);
    COMMAND = file.readEntry("/COMMAND", _COMMAND);
    FILENAME = file.readEntry("/FILENAME", _FILENAME);
    SYSTRAY = file.readNumEntry("/SYSTRAY", _SYSTRAY);
    TRAYALERT = file.readNumEntry("/TRAYALERT", _TRAYALERT);

    QString def = QFont(_FONT).toString();
    QString font = file.readEntry("/FONT", def);
    FONT = QFont();
    FONT.fromString(font);

    file.endGroup();
    file.endGroup();

    debug("POLLTIME = %d\n", POLLTIME);
    debug("PAUSETIME = %d\n", PAUSETIME);
    debug("SHOWTIME = %d\n", SHOWTIME);
    debug("MINLINES = %d\n", MINLINES);
    debug("BUFFSIZE = %d\n", BUFFSIZE);
    debug("COMMAND = %s\n", COMMAND.latin1());
    debug("FILENAME = %s\n", FILENAME.latin1());
    debug("FONT = %s\n", font.latin1());
    debug("SYSTRAY = %d\n", SYSTRAY);
    debug("TRAYALERT = %d\n", TRAYALERT);
}

void KLogConfig::save()
{
    QSettings file;
    debug("Saving config\n");
    
    file.beginGroup("qlogwatch");
    file.beginGroup("Timings");
    file.writeEntry("/POLLTIME", POLLTIME);
    debug("Written POLLTIME = %d\n", POLLTIME);
    file.writeEntry("/PAUSETIME", PAUSETIME);
    debug("Written PAUSETIME = %d\n", PAUSETIME);
    file.writeEntry("/SHOWTIME", SHOWTIME); 
    debug("Written SHOWTIME = %d\n", SHOWTIME);
    file.endGroup();

    file.beginGroup("General");
    file.writeEntry("/MINLINES", MINLINES);
    debug("Written MINLINES = %d\n", MINLINES);
    file.writeEntry("/BUFFSIZE", BUFFSIZE);
    debug("Written BUFFSIZE = %d\n", BUFFSIZE);
    file.writeEntry("/COMMAND", COMMAND);
    debug("Written COMMAND = %s\n", COMMAND.latin1());
    file.writeEntry("/FILENAME", FILENAME);
    debug("Written FILENAME = %s\n", FILENAME.latin1());
    file.writeEntry("/FONT", FONT.toString());
    debug("Written FONT = %s\n", FONT.toString().latin1());
    file.writeEntry("/SYSTRAY", SYSTRAY);
    debug("Written SYSTRAY = %d\n", SYSTRAY);
    file.writeEntry("/TRAYALERT", TRAYALERT);
    debug("Written TRAYALERT = %d\n", TRAYALERT);
    file.endGroup();
    file.endGroup();
}

void KLogConfig::defaults()
{
    debug("Setting defaults\n");
    
    POLLTIME = _POLLTIME;
    debug("Set POLLTIME = %d\n", POLLTIME);
    PAUSETIME = _PAUSETIME;
    debug("Set PAUSETIME = %d\n", PAUSETIME);
    SHOWTIME = _SHOWTIME;
    debug("Set SHOWTIME = %d\n", SHOWTIME);

    MINLINES = _MINLINES;
    debug("Set MINLINES = %d\n", MINLINES);
    BUFFSIZE = _BUFFSIZE;
    debug("Set BUFFSIZE = %d\n", BUFFSIZE);
    COMMAND = _COMMAND;
    debug("Set COMMAND = %s\n", COMMAND.latin1());
    FILENAME = _FILENAME;
    debug("Set FILENAME = %s\n", FILENAME.latin1());
    SYSTRAY = _SYSTRAY;
    debug("Set SYSTRAY = %d\n", SYSTRAY);
    TRAYALERT = _TRAYALERT;
    debug("Set TRAYALERT = %d\n", TRAYALERT);
    FONT = QFont(_FONT);
    debug("Set FONT = %s\n", FONT.toString().latin1());
}

// eof
